"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createFile = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = require("path");
const isFileExists_1 = require("./isFileExists");
const isFolderExist_1 = require("./isFolderExist");
const toCreateFile_1 = require("./toCreateFile");
async function createFile({ filePath, fileName, folderPath, content, options = { createFolder: true, overwriteFile: true, backupFile: true }, }) {
    if (!filePath && (!folderPath || !fileName)) {
        throw new Error("Either 'filePath' or both 'folderPath' and 'fileName' are required.");
    }
    fileName = filePath ? (0, path_1.basename)(filePath) : fileName;
    folderPath = filePath ? (0, path_1.dirname)(filePath) : folderPath;
    if (!filePath) {
        filePath = (0, path_1.join)(folderPath, fileName);
    }
    try {
        await (0, isFolderExist_1.isFolderExist)({
            folderPath,
            createFolder: (options === null || options === void 0 ? void 0 : options.createFolder) || true,
        });
        if (await (0, isFileExists_1.isFileExists)(filePath)) {
            console.warn('File already exists: ' + filePath);
        }
        await (0, toCreateFile_1.toCreateFile)({ filePath, content, options });
        return filePath;
    }
    catch (error) {
        console.error(error);
        return '';
    }
}
exports.createFile = createFile;
async function handleCallback(err) {
    if (err) {
        console.log(`error: ${err.message}`);
        return false;
    }
    return true;
}
async function writeNewFile(filePath, content) {
    try {
        await fs_1.default.promises.writeFile(filePath, content);
        return filePath;
    }
    catch (error) {
        throw error;
    }
}
async function toCreateFolder(folderPath) {
    try {
        await fs_1.default.promises.mkdir(folderPath, { recursive: true });
        return true;
    }
    catch (error) {
        console.error(error);
        return false;
    }
}
