"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.isFolderExist = void 0;
const fs_1 = require("fs");
const path_1 = __importDefault(require("path"));
/**
 * Checks if a folder exists at the given path.
 * If the folder does not exist and createFolder is true, it creates the folder.
 * @param {string} folderPath - The path of the folder to check.
 * @param {boolean} createFolder - If true, create the folder if it doesn't exist.
 * @returns {Promise<boolean>} - Returns true if the folder exists or is created successfully, otherwise false.
 */
async function isFolderExist({ folderPath, createFolder, }) {
    try {
        const folders = folderPath.split(path_1.default.sep);
        for (let i = 1; i <= folders.length; i++) {
            const partialPath = path_1.default.join(...folders.slice(0, i));
            try {
                await fs_1.promises.access(partialPath, fs_1.constants.R_OK | fs_1.constants.W_OK);
            }
            catch (error) {
                if (error.code === 'ENOENT' && createFolder) {
                    await fs_1.promises.mkdir(partialPath);
                }
                else {
                    throw error;
                }
            }
        }
        return true;
    }
    catch (error) {
        console.error(`Error checking or creating folder: ${error.message}`);
        return false;
    }
}
exports.isFolderExist = isFolderExist;
